@@ -1,5 +1,5 @@
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.996';
+$Geo::Address::Formatter::VERSION = '1.997';
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 use strict;
@@ -930,7 +930,7 @@ sub _find_unknown_components {
     my $rh_components = shift;
 
     my %h_known   = map  { $_ => 1 } @{$self->{ordered_components}};
-    my @a_unknown = grep { !exists($h_known{$_}) } keys %$rh_components;
+    my @a_unknown = grep { !exists($h_known{$_}) } sort keys %$rh_components;
     return \@a_unknown;
 }
 
@@ -948,7 +948,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.996
+version 1.997
 
 =head1 SYNOPSIS
 
